WWTLayer
========

.. currentmodule:: pywwt.windows.layer

.. autoclass:: WWTLayer
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~WWTLayer.activate
      ~WWTLayer.delete
      ~WWTLayer.get_properties
      ~WWTLayer.get_property
      ~WWTLayer.set_properties
      ~WWTLayer.set_property
      ~WWTLayer.update

   .. rubric:: Methods Documentation

   .. automethod:: activate
   .. automethod:: delete
   .. automethod:: get_properties
   .. automethod:: get_property
   .. automethod:: set_properties
   .. automethod:: set_property
   .. automethod:: update
